@@ -41,7 +41,7 @@ def override_dpy():
     async def send(self: discord.TextChannel, content=None, **kwargs) -> Message:
         channel_id = self.id if not isinstance(self, commands.Context) else self.channel.id
 
-        if isinstance(self, discord.Member):
+        if isinstance(self, discord.Member) or isinstance(self, discord.User):
             if self.dm_channel == None:
                 dm_chnl = await self.create_dm()
                 channel_id = dm_chnl.id
