@@ -13,7 +13,7 @@ from discord.state import ConnectionState
 from typing import List, Union, Dict
 try:
     from typing import Literal
-except:
+except ImportError:
     from typing_extensions import Literal
 
 logging = setup_logger("discord-ui")
@@ -104,7 +104,7 @@ class Interaction():
         ----------
         content: :class:`str`, optional
             The raw message content
-        tts: :class:`bool` 
+        tts: :class:`bool`
             Whether the message should be send with text-to-speech
         embed: :class:`discord.Embed`
             Embed rich content
@@ -378,7 +378,7 @@ class Message(discord.Message):
         :type: List[:class:`~Button` | :class:`~LinkButton`]
         """
         if hasattr(self, "components") and self.components is not None:
-            return [x for x in self.components if type(x) in [Button, LinkButton]]
+            return [x for x in self.components if isinstance(x, (Button, LinkButton))]
         return []
     @property
     def select_menus(self) -> List[SelectMenu]:
@@ -387,7 +387,7 @@ class Message(discord.Message):
         :type: List[:class:`~SelectMenu`]
         """
         if hasattr(self, "components") and self.components is not None:
-            return [x for x in self.components if type(x) is SelectMenu]
+            return [x for x in self.components if isinstance(x, SelectMenu)]
         return []
     # endregion
 
@@ -466,11 +466,11 @@ class Message(discord.Message):
         Raises
         ------
             :raises: :class:`discord_ui.errors.OutOfValidRange` : The specified range was out of the possible range of the component rows 
-            :raises: :class:`discord_ui.errors.OutOfValidRange` : The specified row was out of the possible range of the component rows 
+            :raises: :class:`discord_ui.errors.OutOfValidRange` : The specified row was out of the possible range of the component rows
         
         """
         comps = []
-        if type(row) is range:
+        if isinstance(row, range):
             for i, _ in enumerate(self.action_rows):
                 if i >= len(self.action_rows) - 1 or i < 0:
                     raise OutOfValidRange("row[" + str(i) + "]", 0, len(self.action_rows) - 1)
@@ -529,7 +529,7 @@ class Message(discord.Message):
         Parameters
         -----------
             event_name: :class:`str`
-                The name of the event which will be awaited [``"select"`` | ``"button"``] 
+                The name of the event which will be awaited [``"select"`` | ``"button"``]
                 
                 .. note::
 
